@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "wiktionary-bro" "1.1.2"
+(define-package "wiktionary-bro" "20251218.2021"
   "Lookup Wiktionary entries."
   '((emacs   "30.1")
     (request "0.3.3"))
   :url "https://github.com/agzam/wiktionary-bro.el"
-  :commit "081449dce747524fa91a657c0972f824af1f4eb4"
-  :revdesc "081449dce747"
+  :commit "def5f3cb1486077cb090da48d77f790b858e7886"
+  :revdesc "def5f3cb1486"
   :keywords '("convenience" "multimedia")
   :authors '(("Ag Ibragimov" . "agzam.ibragimov@gmail.com"))
   :maintainers '(("Ag Ibragimov" . "agzam.ibragimov@gmail.com")))
