@@ -6,8 +6,8 @@
 ;; Maintainer: Ag Ibragimov <agzam.ibragimov@gmail.com>
 ;; Created: December 24, 2022
 ;; Modified: December 18, 2025
-;; Package-Version: 1.1.2
-;; Package-Revision: 081449dce747
+;; Package-Version: 20251218.2021
+;; Package-Revision: def5f3cb1486
 ;; Keywords: convenience multimedia
 ;; Homepage: https://github.com/agzam/wiktionary-bro.el
 ;; Package-Requires: ((emacs "30.1") (request "0.3.3"))
@@ -101,7 +101,9 @@ Each element is (LANG-CODE . LANG-NAME).")
   "Major mode for browsing Wiktionary entries."
   :group 'wiktionary-bro
   (add-hook 'org-open-at-point-functions #'wiktionary-bro--handle-link nil t)
-  (setq-local browse-url-browser-function #'eww-browse-url))
+  (setq-local browse-url-browser-function #'eww-browse-url)
+  (setq-local truncate-lines t)  ; prevent line wrapping for tables
+  (setq-local org-hide-emphasis-markers t))
 
 (defun wiktionary-bro--at-the-beginning-of-word-p (word-point)
   "Predicate to check whether WORD-POINT points to the beginning of the word."
@@ -612,8 +614,6 @@ LANG is the language code, and AVAILABLE-LANGS is an alist of (code . name)."
       (setq-local wiktionary-bro-current-word word)
       (setq-local wiktionary-bro-current-language lang)
       (setq-local wiktionary-bro-available-languages available-langs)
-      (setq-local truncate-lines t)  ; prevent line wrapping for tables
-      (setq-local org-hide-emphasis-markers t)
       (read-only-mode)
       (goto-char (point-min))
       (if same-win-p
